Redis class

Constructors

Redis([RedisOptions? opt])

Properties

connection ↔ RedisConnection
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
option ↔ RedisOptions
getter/setter pair
pool ↔ RedisConnectionPool
getter/setter pair
redisClientType ↔ RedisType
Redis client type subscriber, publisher or normal set and get
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() → Future<void>
Connect to redis connection This call can be optional. If it function did not invoke initially, it will get call on first redis command.
delete(String key) → Future<void>
Delete a key
disconnect() → Future<void>
Disconnect to redis connection
duplicate() → Redis
Duplicate new redis connection
flushdb() → Future<void>
flush all they data from currently selected DB
get(String key) → Future<String?>
Get value of a key
getCommandToGetData(String key) → List<String>
get command to get data from redis
getCommandToSetData(String key, String value, [String? option, dynamic optionValue]) → List<String>
get command to set data to redis
mdelete(List<String> keys) → Future<void>
Delete multiple key
mget(List<String> keys) → Future<List<String?>>
Get value of a key
multi() → RedisMulti
multi commands
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(String channel, String message) → Future<void>
Publish message to a channel
sendCommand(List<String> commandList) → Future
send command to connection
set(String key, String value, [String? option, dynamic optionValue]) → Future
Set key value to redis
setSocket(Socket socket) → Redis
Set custom socket
subscribe(Object channel) → Future<RedisSubscriber>
Subscribe to channel
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited