RedisConnection class

Constructors

RedisConnection([RedisOptions? opt])

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBusy ↔ bool
check connection is free
getter/setter pair
option ↔ RedisOptions
Redis option
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ RedisConnectionStatus
Current status of redis connection
getter/setter pair
subscribeListeners → Map<List<String>, RedisSubscriber>
Listeners of subscribers
final

Methods

connect() → Future<void>
Connect to redis connection
destroy() → void
Disconnect redis connection
disconnect() → Future<void>
Disconnect redis connection
getStatus() → String
Get current connection status
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendCommand(List<String> commandList) → Future
Send redis command
setSocket(Socket socket) → void
Set custom socket
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited