RedisOptions class

Constructors

RedisOptions({String keyPrefix = '', String host = '127.0.0.1', int port = 6379, bool secure = false, Duration connectTimeout = const Duration(seconds: 10), String? username, String? password, int db = 0, Duration retryStrategy(int)?, void onError(dynamic)?, int maxConnection = 10, Duration idleTimeout = const Duration(seconds: 10), bool onBadCertificate(X509Certificate)?})

Properties

connectTimeout → Duration
timeout value for socket connection
final
db ↔ int
database index defaults to 0
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String
redis host
getter/setter pair
idleTimeout ↔ Duration
timeout duration of idle connection in the pool, default to 10s
getter/setter pair
keyPrefix ↔ String
key prefix
getter/setter pair
maxConnection ↔ int
maximum connection pool, default to 10;
getter/setter pair
onBadCertificate ↔ bool Function(X509Certificate)?
An optional callback for handling server SSL certificate validation.
getter/setter pair
onError ↔ void Function(dynamic)?
error handler
getter/setter pair
password → String?
redis password
final
port ↔ int
redis port
getter/setter pair
retryStrategy → Duration Function(int)?
retry strategy defaults to min(50 * times, 2000)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secure → bool
use secure socket
final
username → String?
redis username
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited